@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import, print_function
 import json
 import logging
 import os
@@ -20,12 +17,12 @@ def find_site_path(pkg, site_dir=None):
         base_name = dist.project_name if dist.project_name else dist.key
         name = None
         if "top_level.txt" in dist.metadata_listdir(""):
-            name = next(iter([l.strip() for l in dist.get_metadata_lines("top_level.txt") if l is not None]), None)
+            name = next(iter([line.strip() for line in dist.get_metadata_lines("top_level.txt") if line is not None]), None)
         if name is None:
             name = pkg_resources.safe_name(base_name).replace("-", "_")
         if not any(pkg == _ for _ in [base_name, name]):
             continue
-        path_options = [name, "{0}.py".format(name)]
+        path_options = [name, f"{name}.py"]
         path_options = [os.path.join(root, p) for p in path_options if p is not None]
         path = next(iter(p for p in path_options if os.path.exists(p)), None)
         if path is not None:
@@ -80,23 +77,31 @@ def which(*args, **kwargs):
 
 
 def handle_parsed_args(parsed):
+    if "PIPENV_VERBOSITY" in os.environ:
+        parsed.verbose = int(os.getenv("PIPENV_VERBOSITY"))
     if parsed.debug:
         parsed.verbose = max(parsed.verbose, 2)
     if parsed.verbose > 1:
         logging.getLogger("notpip").setLevel(logging.DEBUG)
     elif parsed.verbose > 0:
         logging.getLogger("notpip").setLevel(logging.INFO)
+        logger = logging.getLogger(
+            "pipenv.patched.notpip._internal.resolution.resolvelib.reporter"
+        )
+        logger.addHandler(logging.StreamHandler())
+        logger.setLevel(logging.INFO)
+        os.environ["PIP_RESOLVER_DEBUG"] = ""
     os.environ["PIPENV_VERBOSITY"] = str(parsed.verbose)
     if "PIPENV_PACKAGES" in os.environ:
         parsed.packages += os.environ.get("PIPENV_PACKAGES", "").strip().split("\n")
     return parsed
 
 
-class Entry(object):
+class Entry:
     """A resolved entry from a resolver run"""
 
     def __init__(self, name, entry_dict, project, resolver, reverse_deps=None, dev=False):
-        super(Entry, self).__init__()
+        super().__init__()
         from pipenv.vendor.requirementslib.models.utils import tomlkit_value_to_python
         self.name = name
         if isinstance(entry_dict, dict):
@@ -173,7 +178,7 @@ class Entry(object):
         markers = set()
         keys_in_dict = [k for k in marker_keys if k in entry_dict]
         markers = {
-            normalize_marker_str("{k} {v}".format(k=k, v=entry_dict.pop(k)))
+            normalize_marker_str(f"{k} {entry_dict.pop(k)}")
             for k in keys_in_dict
         }
         if "markers" in entry_dict:
@@ -216,18 +221,17 @@ class Entry(object):
         from pipenv.vendor.requirementslib.models.markers import normalize_marker_str
         if not marker:
             return None
-        from pipenv.vendor import six
         from pipenv.vendor.vistir.compat import Mapping
         marker_str = None
         if isinstance(marker, Mapping):
             marker_dict, _ = Entry.get_markers_from_dict(marker)
             if marker_dict:
-                marker_str = "{0}".format(marker_dict.popitem()[1])
+                marker_str = f"{marker_dict.popitem()[1]}"
         elif isinstance(marker, (list, set, tuple)):
             marker_str = " and ".join([normalize_marker_str(m) for m in marker if m])
-        elif isinstance(marker, six.string_types):
-            marker_str = "{0}".format(normalize_marker_str(marker))
-        if isinstance(marker_str, six.string_types):
+        elif isinstance(marker, str):
+            marker_str = f"{normalize_marker_str(marker)}"
+        if isinstance(marker_str, str):
             return marker_str
         return None
 
@@ -317,9 +321,9 @@ class Entry(object):
         if not any(specifier.startswith(k) for k in Specifier._operators.keys()):
             if specifier.strip().lower() in ["any", "<any>", "*"]:
                 return "*"
-            specifier = "=={0}".format(specifier)
+            specifier = f"=={specifier}"
         elif specifier.startswith("==") and specifier.count("=") > 3:
-            specifier = "=={0}".format(specifier.lstrip("="))
+            specifier = "=={}".format(specifier.lstrip("="))
         return specifier
 
     @staticmethod
@@ -448,7 +452,7 @@ class Entry(object):
                 self.can_use_updated = False
             satisfied_by_value = getattr(constraint, "satisfied_by", None)
             if satisfied_by_value:
-                satisfied_by = "{0}".format(
+                satisfied_by = "{}".format(
                     self.clean_specifier(str(satisfied_by_value.version))
                 )
                 satisfied_by_versions.add(satisfied_by)
@@ -514,7 +518,6 @@ class Entry(object):
         :raises: :exc:`pipenv.exceptions.DependencyConflict` if the constraints dont exist
         """
         from pipenv.exceptions import DependencyConflict
-        from pipenv.environments import is_verbose
 
         constraints = self.get_constraints()
         pinned_version = self.updated_version
@@ -524,10 +527,10 @@ class Entry(object):
             if pinned_version and not constraint.req.specifier.contains(
                 str(pinned_version), prereleases=True
             ):
-                if is_verbose():
-                    print("Tried constraint: {0!r}".format(constraint), file=sys.stderr)
+                if self.project.s.is_verbose():
+                    print(f"Tried constraint: {constraint!r}", file=sys.stderr)
                 msg = (
-                    "Cannot resolve conflicting version {0}{1} while {2}{3} is "
+                    "Cannot resolve conflicting version {}{} while {}{} is "
                     "locked.".format(
                         self.name, constraint.req.specifier,
                         self.name, self.updated_specifier
@@ -543,8 +546,8 @@ class Entry(object):
             if not parent.validate_specifiers():
                 from pipenv.exceptions import DependencyConflict
                 msg = (
-                    "Cannot resolve conflicting versions: (Root: {0}) {1}{2} (Pipfile) "
-                    "Incompatible with {3}{4} (resolved)\n".format(
+                    "Cannot resolve conflicting versions: (Root: {}) {}{} (Pipfile) "
+                    "Incompatible with {}{} (resolved)\n".format(
                         self.name, parent.pipfile_name,
                         parent.pipfile_entry.requirement.specifiers, parent.name,
                         parent.updated_specifiers
@@ -565,7 +568,7 @@ class Entry(object):
                 except AttributeError:
                     result = getattr(entry, key)
             except AttributeError:
-                result = super(Entry, self).__getattribute__(key)
+                result = super().__getattribute__(key)
             return result
         if any(key.startswith(v) for v in old_version):
             lockfile_entry = Entry.__getattribute__(self, "lockfile_entry")
@@ -576,9 +579,9 @@ class Entry(object):
                 except AttributeError:
                     result = getattr(lockfile_entry, key)
             except AttributeError:
-                result = super(Entry, self).__getattribute__(key)
+                result = super().__getattribute__(key)
             return result
-        return super(Entry, self).__getattribute__(key)
+        return super().__getattribute__(key)
 
 
 def clean_results(results, resolver, project, dev=False):
@@ -646,7 +649,7 @@ def parse_packages(packages, pre, clear, system, requirements_dir=None):
     from pipenv.utils import parse_indexes
     parsed_packages = []
     for package in packages:
-        indexes, trusted_hosts, line = parse_indexes(package)
+        *_, line = parse_indexes(package)
         line = " ".join(line)
         pf = dict()
         req = Requirement.from_line(line)
@@ -679,8 +682,6 @@ def resolve_packages(pre, clear, verbose, system, write, requirements_dir, packa
     )
 
     def resolve(packages, pre, project, sources, clear, system, requirements_dir=None):
-        from pipenv.patched.piptools import logging as piptools_logging
-        piptools_logging.log.verbosity = 1 if verbose else 0
         return resolve_deps(
             packages,
             which,
@@ -692,7 +693,8 @@ def resolve_packages(pre, clear, verbose, system, write, requirements_dir, packa
             req_dir=requirements_dir
         )
 
-    from pipenv.core import project
+    from pipenv.project import Project
+    project = Project()
     sources = (
         replace_pypi_sources(project.pipfile_sources, pypi_mirror_source)
         if pypi_mirror_source
@@ -741,9 +743,9 @@ def _main(pre, clear, verbose, system, write, requirements_dir, packages, parse_
         resolve_packages(pre, clear, verbose, system, write, requirements_dir, packages, dev)
 
 
-def main():
+def main(argv=None):
     parser = get_parser()
-    parsed, remaining = parser.parse_known_args()
+    parsed, remaining = parser.parse_known_args(argv)
     _patch_path(pipenv_site=parsed.pipenv_site)
     import warnings
     from pipenv.vendor.vistir.compat import ResourceWarning
@@ -751,9 +753,9 @@ def main():
     warnings.simplefilter("ignore", category=ResourceWarning)
     replace_with_text_stream("stdout")
     replace_with_text_stream("stderr")
-    os.environ["PIP_DISABLE_PIP_VERSION_CHECK"] = str("1")
-    os.environ["PYTHONIOENCODING"] = str("utf-8")
-    os.environ["PYTHONUNBUFFERED"] = str("1")
+    os.environ["PIP_DISABLE_PIP_VERSION_CHECK"] = "1"
+    os.environ["PYTHONIOENCODING"] = "utf-8"
+    os.environ["PYTHONUNBUFFERED"] = "1"
     parsed = handle_parsed_args(parsed)
     _main(parsed.pre, parsed.clear, parsed.verbose, parsed.system, parsed.write,
           parsed.requirements_dir, parsed.packages, parse_only=parsed.parse_only,
