@@ -428,6 +428,7 @@ class Resolver:
         self._parsed_constraints = None
         self._resolver = None
         self._finder = None
+        self._ignore_compatibility_finder = None
         self._session = None
         self._constraint_file = None
         self._pip_options = None
@@ -521,10 +522,7 @@ class Resolver:
         if project is None:
             from .project import Project
             project = Project()
-        url = None
-        indexes, trusted_hosts, remainder = parse_indexes(line)
-        if indexes:
-            url = indexes[0]
+        index, extra_index, trust_host, remainder = parse_indexes(line)
         line = " ".join(remainder)
         req = None  # type: Requirement
         try:
@@ -539,10 +537,10 @@ class Resolver:
                     raise ResolutionFailure(f"Failed to resolve requirement from line: {line!s}")
             else:
                 raise ResolutionFailure(f"Failed to resolve requirement from line: {line!s}")
-        if url:
+        if index:
             try:
                 index_lookup[req.normalized_name] = project.get_source(
-                    url=url, refresh=True).get("name")
+                    url=index, refresh=True).get("name")
             except TypeError:
                 pass
         try:
@@ -556,12 +554,6 @@ class Resolver:
             markers_lookup[req.normalized_name] = req.markers.replace('"', "'")
         return req, index_lookup, markers_lookup
 
-    @classmethod
-    def get_deps_from_line(cls, line):
-        # type: (str) -> Tuple[Set[str], Dict[str, Dict[str, Union[str, bool, List[str]]]]]
-        req, _, _ = cls.parse_line(line)
-        return cls.get_deps_from_req(req)
-
     @classmethod
     def get_deps_from_req(cls, req, resolver=None, resolve_vcs=True):
         # type: (Requirement, Optional["Resolver"], bool) -> Tuple[Set[str], Dict[str, Dict[str, Union[str, bool, List[str]]]]]
@@ -725,7 +717,7 @@ class Resolver:
             self._pip_command = self._get_pip_command()
         return self._pip_command
 
-    def prepare_pip_args(self, use_pep517=False, build_isolation=True):
+    def prepare_pip_args(self, use_pep517=None, build_isolation=True):
         pip_args = []
         if self.sources:
             pip_args = prepare_pip_source_args(self.sources, pip_args)
@@ -807,6 +799,22 @@ class Resolver:
             )
         return self._finder
 
+    @property
+    def ignore_compatibility_finder(self):
+        from pipenv.vendor.pip_shims import shims
+        if self._ignore_compatibility_finder is None:
+            ignore_compatibility_finder = shims.get_package_finder(
+                install_cmd=self.pip_command,
+                options=self.pip_options,
+                session=self.session,
+            )
+            # It would be nice if `shims.get_package_finder` took an
+            # `ignore_compatibility` parameter, but that's some vendorered code
+            # we'd rather avoid touching.
+            ignore_compatibility_finder._ignore_compatibility = True
+            self._ignore_compatibility_finder = ignore_compatibility_finder
+        return self._ignore_compatibility_finder
+
     @property
     def parsed_constraints(self):
         from pipenv.vendor.pip_shims import shims
@@ -839,7 +847,6 @@ class Resolver:
         )
 
         with global_tempdir_manager(), get_requirement_tracker() as req_tracker, TemporaryDirectory(suffix="-build", prefix="pipenv-") as directory:
-            os.environ["PIP_USE_PEP517"] = "false"
             pip_options = self.pip_options
             finder = self.finder
             wheel_cache = WheelCache(pip_options.cache_dir, pip_options.format_control)
@@ -960,7 +967,7 @@ class Resolver:
             if hashes:
                 return hashes
 
-        applicable_candidates = self.finder.find_best_candidate(
+        applicable_candidates = self.ignore_compatibility_finder.find_best_candidate(
             ireq.name, ireq.specifier
         ).iter_applicable()
         return {
@@ -1636,6 +1643,30 @@ def get_url_name(url):
     return urllib3_util.parse_url(url).host
 
 
+def get_host_and_port(url):
+    """Get the host, or the host:port pair if port is explicitly included, for the given URL.
+
+    Examples:
+    >>> get_host_and_port('example.com')
+    'example.com'
+    >>> get_host_and_port('example.com:443')
+    'example.com:443'
+    >>> get_host_and_port('http://example.com')
+    'example.com'
+    >>> get_host_and_port('https://example.com/')
+    'example.com'
+    >>> get_host_and_port('https://example.com:8081')
+    'example.com:8081'
+    >>> get_host_and_port('ssh://example.com')
+    'example.com'
+
+    :param url: the URL string to parse
+    :return: a string with the host:port pair if the URL includes port number explicitly; otherwise, returns host only
+    """
+    url = urllib3_util.parse_url(url)
+    return '{}:{}'.format(url.host, url.port) if url.port else url.host
+
+
 def get_canonical_names(packages):
     """Canonicalize a list of packages and return a set of canonical names"""
     from .vendor.packaging.utils import canonicalize_name
@@ -2058,24 +2089,24 @@ def looks_like_dir(path):
     return any(sep in path for sep in seps)
 
 
-def parse_indexes(line):
+def parse_indexes(line, strict=False):
     from argparse import ArgumentParser
-    parser = ArgumentParser("indexes")
-    parser.add_argument(
-        "--index", "-i", "--index-url",
-        metavar="index_url", action="store", nargs="?",
-    )
-    parser.add_argument(
-        "--extra-index-url", "--extra-index",
-        metavar="extra_indexes", action="append",
-    )
-    parser.add_argument("--trusted-host", metavar="trusted_hosts", action="append")
+
+    comment_re = re.compile(r"(?:^|\s+)#.*$")
+    line = comment_re.sub("", line)
+    parser = ArgumentParser("indexes", allow_abbrev=False)
+    parser.add_argument("-i", "--index-url", dest="index")
+    parser.add_argument("--extra-index-url", dest="extra_index")
+    parser.add_argument("--trusted-host", dest="trusted_host")
     args, remainder = parser.parse_known_args(line.split())
-    index = [] if not args.index else [args.index]
-    extra_indexes = [] if not args.extra_index_url else args.extra_index_url
-    indexes = index + extra_indexes
-    trusted_hosts = args.trusted_host if args.trusted_host else []
-    return indexes, trusted_hosts, remainder
+    index = args.index
+    extra_index = args.extra_index
+    trusted_host = args.trusted_host
+    if strict and sum(
+        bool(arg) for arg in (index, extra_index, trusted_host, remainder)
+    ) > 1:
+        raise ValueError("Index arguments must be on their own lines.")
+    return index, extra_index, trusted_host, remainder
 
 
 @contextmanager
